@@ -171,6 +171,20 @@ def _remove_cells_with_tags(nb, tags):
     return nb
 
 
+def _remove_cells_outputs(nb):
+    for cell in nb.cells:
+        if "outputs" in cell:
+            cell["outputs"] = []
+    return nb
+
+
+def _remove_cells_execution_count(nb):
+    for cell in nb.cells:
+        if "execution_count" in cell:
+            cell["execution_count"] = None
+    return nb
+
+
 class PloomberClient:
     """PloomberClient executes Jupyter notebooks
 
@@ -199,6 +213,11 @@ class PloomberClient:
 
     Notes
     -----
+    .. versionchanged:: 0.0.25dev
+        Removed cell outputs and execution count
+        Added error messages to output notebook during an exception
+        Temporary Fixed the stderr and stdout streams of ploomber engine
+
     .. versionchanged:: 0.0.23
         Added ``cwd`` argument.
 
@@ -265,6 +284,8 @@ class PloomberClient:
         cwd=".",
     ):
         self._nb = _remove_cells_with_tags(nb, remove_tagged_cells)
+        self._nb = _remove_cells_outputs(self._nb)
+        self._nb = _remove_cells_execution_count(self._nb)
         self._shell = None
         self._display_stdout = display_stdout
         self._debug_later = debug_later
@@ -342,7 +363,7 @@ class PloomberClient:
             progress_bar=progress_bar,
             debug_later=debug_later,
             remove_tagged_cells=remove_tagged_cells,
-            cwd=cwd
+            cwd=cwd,
         )
 
     def execute_cell(self, cell, cell_index, execution_count, store_history):
@@ -351,7 +372,10 @@ class PloomberClient:
 
         # results are published in different places. Here we grab all of them
         # and return them
-        with patch_sys_std_out_err() as (stdout_stream, stderr_stream):
+        with patch_sys_std_out_err(self._display_stdout) as (
+            stdout_stream,
+            stderr_stream,
+        ):
             self.hook_cell_pre(cell)
             result = self._shell.run_cell(cell["source"])
             self.hook_cell_post(cell)
@@ -362,7 +386,8 @@ class PloomberClient:
 
         if stdout:
             if self._display_stdout:
-                print("".join([line.strip() for line in stdout]))
+                pass
+                # print("".join([line for line in stdout]),end='')
 
             output.extend(_process_stdout(stdout, result=result))
 
@@ -385,6 +410,26 @@ class PloomberClient:
         cell.execution_count = execution_count
 
         if not result.success:
+
+            # Append to the position above cell
+            self._nb.cells.insert(
+                cell_index,
+                nbformat.v4.new_markdown_cell(
+                    source='## <span style="color:red">Ploomber Engine raised an'
+                    + " exception due to the cell below </span>",
+                    metadata={"tags": ["ploomber-engine-error-cell"]},
+                ),
+            )
+
+            # Append to the start
+            self._nb.cells.insert(
+                0,
+                nbformat.v4.new_markdown_cell(
+                    source='## <span style="color:red">An Exception has'
+                    + f" occured at cell {cell.execution_count}</span>",
+                    metadata={"tags": ["ploomber-engine-error-cell"]},
+                ),
+            )
             result.raise_error()
 
         return output
@@ -399,6 +444,9 @@ class PloomberClient:
 
         Notes
         -----
+        .. versionchanged:: 0.0.25dev
+            Added error messages to output notebook during an exception
+
         .. versionchanged:: 0.0.19
             Added ``parameters`` argument
         """
@@ -607,12 +655,23 @@ class PloomberManagedClient(PloomberClient):
 
 
 class IO(StringIO):
-    def __init__(self, initial_value="", newline="\n"):
+    def __init__(self, default, std_type, display=True, newline="\n", initial_value=""):
         super().__init__(initial_value=initial_value, newline=newline)
+        self.default = default
+        self.std_type = std_type
+        self.display = display
         self._values = []
 
     def write(self, s):
         self._values.append(s)
+
+        # Temporary Fix
+        if self.display:
+            if self.std_type == "out":
+                if s != "\n":
+                    self.default.write("\n" + s + "\n")
+            else:
+                self.default.write(s)
         super().write(s)
 
     def get_separated_values(self):
@@ -620,13 +679,14 @@ class IO(StringIO):
 
 
 @contextlib.contextmanager
-def patch_sys_std_out_err():
+def patch_sys_std_out_err(display_output):
     """Path sys.{stout, sterr} to capture output"""
     # keep a reference to the system ones
     stdout, stderr = sys.stdout, sys.stderr
 
     # patch them
-    stdout_stream, stderr_stream = IO(), StringIO()
+    stdout_stream = IO(default=stdout, std_type="out", display=display_output)
+    stderr_stream = IO(default=stderr, std_type="err")
     sys.stdout, sys.stderr = stdout_stream, stderr_stream
 
     try:
